#!D:\bld\gdal-split_1602162169053\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==3.1.3','gdalcompare.py'
__requires__ = 'GDAL==3.1.3'
__import__('pkg_resources').run_script('GDAL==3.1.3', 'gdalcompare.py')
